@@ -1,28 +1,55 @@
-from mikro.scalars import Store, File, ArrayInput, Parquet, Upload, DataFrame
-from mikro.traits import ROI, Representation, Vectorizable, Table
-from mikro.funcs import asubscribe, aexecute, execute, subscribe
-from typing import Optional, Literal, Dict, Iterator, List, AsyncIterator
+from typing import Optional, Dict, List, AsyncIterator, Iterator, Literal
+from rath.scalars import ID
+from mikro.funcs import asubscribe, execute, aexecute, subscribe
+from mikro.scalars import (
+    Parquet,
+    File,
+    FeatureValue,
+    ArrayInput,
+    Store,
+    MetricValue,
+    DataFrame,
+)
+from pydantic import Field, BaseModel
+from datetime import datetime
+from mikro.traits import Representation, Table, Vectorizable, ROI
 from enum import Enum
 from mikro.rath import MikroRath
-from pydantic import Field, BaseModel
-from rath.scalars import ID
 
 
-class AvailableModels(str, Enum):
-    GRUNNLAG_ANIMAL = "GRUNNLAG_ANIMAL"
+class CommentableModels(str, Enum):
+    GRUNNLAG_USERMETA = "GRUNNLAG_USERMETA"
+    GRUNNLAG_ANTIBODY = "GRUNNLAG_ANTIBODY"
     GRUNNLAG_EXPERIMENT = "GRUNNLAG_EXPERIMENT"
     GRUNNLAG_EXPERIMENTALGROUP = "GRUNNLAG_EXPERIMENTALGROUP"
-    GRUNNLAG_REPRESENTATION = "GRUNNLAG_REPRESENTATION"
-    GRUNNLAG_THUMBNAIL = "GRUNNLAG_THUMBNAIL"
-    GRUNNLAG_SAMPLE = "GRUNNLAG_SAMPLE"
-    GRUNNLAG_ROI = "GRUNNLAG_ROI"
+    GRUNNLAG_ANIMAL = "GRUNNLAG_ANIMAL"
     GRUNNLAG_OMEROFILE = "GRUNNLAG_OMEROFILE"
+    GRUNNLAG_SAMPLE = "GRUNNLAG_SAMPLE"
+    GRUNNLAG_REPRESENTATION = "GRUNNLAG_REPRESENTATION"
+    GRUNNLAG_OMERO = "GRUNNLAG_OMERO"
     GRUNNLAG_METRIC = "GRUNNLAG_METRIC"
-    GRUNNLAG_ANTIBODY = "GRUNNLAG_ANTIBODY"
-    GRUNNLAG_USERMETA = "GRUNNLAG_USERMETA"
+    GRUNNLAG_THUMBNAIL = "GRUNNLAG_THUMBNAIL"
+    GRUNNLAG_ROI = "GRUNNLAG_ROI"
     GRUNNLAG_LABEL = "GRUNNLAG_LABEL"
-    GRUNNLAG_SIZEFEATURE = "GRUNNLAG_SIZEFEATURE"
-    GRUNNLAG_COMMENT = "GRUNNLAG_COMMENT"
+    GRUNNLAG_FEATURE = "GRUNNLAG_FEATURE"
+    BORD_TABLE = "BORD_TABLE"
+
+
+class SharableModels(str, Enum):
+    GRUNNLAG_USERMETA = "GRUNNLAG_USERMETA"
+    GRUNNLAG_ANTIBODY = "GRUNNLAG_ANTIBODY"
+    GRUNNLAG_EXPERIMENT = "GRUNNLAG_EXPERIMENT"
+    GRUNNLAG_EXPERIMENTALGROUP = "GRUNNLAG_EXPERIMENTALGROUP"
+    GRUNNLAG_ANIMAL = "GRUNNLAG_ANIMAL"
+    GRUNNLAG_OMEROFILE = "GRUNNLAG_OMEROFILE"
+    GRUNNLAG_SAMPLE = "GRUNNLAG_SAMPLE"
+    GRUNNLAG_REPRESENTATION = "GRUNNLAG_REPRESENTATION"
+    GRUNNLAG_OMERO = "GRUNNLAG_OMERO"
+    GRUNNLAG_METRIC = "GRUNNLAG_METRIC"
+    GRUNNLAG_THUMBNAIL = "GRUNNLAG_THUMBNAIL"
+    GRUNNLAG_ROI = "GRUNNLAG_ROI"
+    GRUNNLAG_LABEL = "GRUNNLAG_LABEL"
+    GRUNNLAG_FEATURE = "GRUNNLAG_FEATURE"
     BORD_TABLE = "BORD_TABLE"
 
 
@@ -101,11 +128,39 @@ class RoiTypeInput(str, Enum):
     "Unknown"
 
 
+class DescendendInput(BaseModel):
+    children: Optional[List[Optional["DescendendInput"]]]
+    typename: Optional[str]
+    "The type of the descendent"
+    user: Optional[str]
+    "The user that is mentioned"
+    bold: Optional[bool]
+    "Is this a bold leaf?"
+    italic: Optional[bool]
+    "Is this a italic leaf?"
+    code: Optional[bool]
+    "Is this a code leaf?"
+    text: Optional[str]
+    "The text of the leaf"
+
+
+class GroupAssignmentInput(BaseModel):
+    permissions: List[Optional[str]]
+    group: ID
+
+
+class UserAssignmentInput(BaseModel):
+    permissions: List[Optional[str]]
+    user: str
+    "The user email"
+
+
 class OmeroRepresentationInput(BaseModel):
     planes: Optional[List[Optional["PlaneInput"]]]
     channels: Optional[List[Optional["ChannelInput"]]]
     physical_size: Optional["PhysicalSizeInput"] = Field(alias="physicalSize")
     scale: Optional[List[Optional[float]]]
+    acquisition_date: Optional[datetime] = Field(alias="acquisitionDate")
 
 
 class PlaneInput(BaseModel):
@@ -147,33 +202,6 @@ class InputVector(BaseModel, Vectorizable):
     "T-coordinate"
 
 
-class GroupAssignmentInput(BaseModel):
-    permissions: List[Optional[str]]
-    group: ID
-
-
-class UserAssignmentInput(BaseModel):
-    permissions: List[Optional[str]]
-    user: str
-    "The user email"
-
-
-class DescendendInput(BaseModel):
-    children: Optional[List[Optional["DescendendInput"]]]
-    typename: Optional[str]
-    "The type of the descendent"
-    user: Optional[str]
-    "The user that is mentioned"
-    bold: Optional[bool]
-    "Is this a bold leaf?"
-    italic: Optional[bool]
-    "Is this a italic leaf?"
-    code: Optional[bool]
-    "Is this a code leaf?"
-    text: Optional[str]
-    "The text of the leaf"
-
-
 class RepresentationFragmentSample(BaseModel):
     """Samples are storage containers for representations. A Sample is to be understood analogous to a Biological Sample. It existed in Time (the time of acquisiton and experimental procedure),
     was measured in space (x,y,z) and in different modalities (c). Sample therefore provide a datacontainer where each Representation of
@@ -185,6 +213,11 @@ class RepresentationFragmentSample(BaseModel):
     name: str
 
 
+class RepresentationFragmentOmero(BaseModel):
+    typename: Optional[Literal["Omero"]] = Field(alias="__typename")
+    scale: Optional[List[Optional[float]]]
+
+
 class RepresentationFragment(Representation, BaseModel):
     typename: Optional[Literal["Representation"]] = Field(alias="__typename")
     sample: Optional[RepresentationFragmentSample]
@@ -197,6 +230,7 @@ class RepresentationFragment(Representation, BaseModel):
     "The Representation can have varying types, consult your API"
     name: Optional[str]
     "Cleartext name"
+    omero: Optional[RepresentationFragmentOmero]
 
 
 class ThumbnailFragment(BaseModel):
@@ -205,6 +239,34 @@ class ThumbnailFragment(BaseModel):
     image: Optional[str]
 
 
+class MetricFragmentRep(Representation, BaseModel):
+    """A Representation is a multi-dimensional Array that can do what ever it wants
+
+
+    @elements/rep:latest"""
+
+    typename: Optional[Literal["Representation"]] = Field(alias="__typename")
+    id: ID
+
+
+class MetricFragmentCreator(BaseModel):
+    typename: Optional[Literal["User"]] = Field(alias="__typename")
+    id: ID
+
+
+class MetricFragment(BaseModel):
+    typename: Optional[Literal["Metric"]] = Field(alias="__typename")
+    id: ID
+    rep: Optional[MetricFragmentRep]
+    "The Representatoin this Metric belongs to"
+    key: str
+    "The Key"
+    value: Optional[MetricValue]
+    "Value"
+    creator: Optional[MetricFragmentCreator]
+    created_at: datetime = Field(alias="createdAt")
+
+
 class ROIFragmentVectors(BaseModel):
     typename: Optional[Literal["Vector"]] = Field(alias="__typename")
     x: Optional[float]
@@ -226,12 +288,10 @@ class ROIFragmentRepresentation(Representation, BaseModel):
 
 
 class ROIFragmentCreator(BaseModel):
-    """A reflection on the real User"""
-
     typename: Optional[Literal["User"]] = Field(alias="__typename")
     email: str
-    color: Optional[str]
-    "The associated color for this user"
+    color: str
+    "The color of the user"
 
 
 class ROIFragment(ROI, BaseModel):
@@ -245,8 +305,6 @@ class ROIFragment(ROI, BaseModel):
 
 
 class TableFragmentCreator(BaseModel):
-    """A reflection on the real User"""
-
     typename: Optional[Literal["User"]] = Field(alias="__typename")
     email: str
 
@@ -322,11 +380,10 @@ class OmeroFileFragment(BaseModel):
     id: ID
     name: str
     file: Optional[File]
+    type: OmeroFileType
 
 
 class ExperimentFragmentCreator(BaseModel):
-    """A reflection on the real User"""
-
     typename: Optional[Literal["User"]] = Field(alias="__typename")
     email: str
 
@@ -365,7 +422,7 @@ class Get_omero_fileQuery(BaseModel):
         id: ID
 
     class Meta:
-        document = "fragment OmeroFile on OmeroFile {\n  id\n  name\n  file\n}\n\nquery get_omero_file($id: ID!) {\n  omerofile(id: $id) {\n    ...OmeroFile\n  }\n}"
+        document = "fragment OmeroFile on OmeroFile {\n  id\n  name\n  file\n  type\n}\n\nquery get_omero_file($id: ID!) {\n  omerofile(id: $id) {\n    ...OmeroFile\n  }\n}"
 
 
 class Expand_omerofileQuery(BaseModel):
@@ -376,7 +433,7 @@ class Expand_omerofileQuery(BaseModel):
         id: ID
 
     class Meta:
-        document = "fragment OmeroFile on OmeroFile {\n  id\n  name\n  file\n}\n\nquery expand_omerofile($id: ID!) {\n  omerofile(id: $id) {\n    ...OmeroFile\n  }\n}"
+        document = "fragment OmeroFile on OmeroFile {\n  id\n  name\n  file\n  type\n}\n\nquery expand_omerofile($id: ID!) {\n  omerofile(id: $id) {\n    ...OmeroFile\n  }\n}"
 
 
 class Search_omerofileQueryOmerofiles(BaseModel):
@@ -396,6 +453,33 @@ class Search_omerofileQuery(BaseModel):
         document = "query search_omerofile($search: String!) {\n  omerofiles(name: $search) {\n    value: id\n    label: name\n  }\n}"
 
 
+class Get_labelQueryLabelforFeatures(BaseModel):
+    typename: Optional[Literal["Feature"]] = Field(alias="__typename")
+    id: ID
+    key: str
+    "The sKesyss"
+    value: Optional[FeatureValue]
+    "Value"
+
+
+class Get_labelQueryLabelfor(BaseModel):
+    typename: Optional[Literal["Label"]] = Field(alias="__typename")
+    id: ID
+    features: List[Get_labelQueryLabelforFeatures]
+
+
+class Get_labelQuery(BaseModel):
+    label_for: Optional[Get_labelQueryLabelfor] = Field(alias="labelFor")
+    "Get a label for a specific instance on a specific representation"
+
+    class Arguments(BaseModel):
+        representation: ID
+        instance: int
+
+    class Meta:
+        document = "query get_label($representation: ID!, $instance: Int!) {\n  labelFor(representation: $representation, instance: $instance) {\n    id\n    features {\n      id\n      key\n      value\n    }\n  }\n}"
+
+
 class Expand_representationQuery(BaseModel):
     """Creates a new representation"""
 
@@ -406,7 +490,7 @@ class Expand_representationQuery(BaseModel):
         id: ID
 
     class Meta:
-        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n}\n\nquery expand_representation($id: ID!) {\n  representation(id: $id) {\n    ...Representation\n  }\n}"
+        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n  omero {\n    scale\n  }\n}\n\nquery expand_representation($id: ID!) {\n  representation(id: $id) {\n    ...Representation\n  }\n}"
 
 
 class Get_representationQuery(BaseModel):
@@ -417,7 +501,7 @@ class Get_representationQuery(BaseModel):
         id: ID
 
     class Meta:
-        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n}\n\nquery get_representation($id: ID!) {\n  representation(id: $id) {\n    ...Representation\n  }\n}"
+        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n  omero {\n    scale\n  }\n}\n\nquery get_representation($id: ID!) {\n  representation(id: $id) {\n    ...Representation\n  }\n}"
 
 
 class Search_representationQueryOptions(Representation, BaseModel):
@@ -457,7 +541,7 @@ class Get_random_repQuery(BaseModel):
         pass
 
     class Meta:
-        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n}\n\nquery get_random_rep {\n  randomRepresentation {\n    ...Representation\n  }\n}"
+        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n  omero {\n    scale\n  }\n}\n\nquery get_random_rep {\n  randomRepresentation {\n    ...Representation\n  }\n}"
 
 
 class My_accessiblesQuery(BaseModel):
@@ -467,7 +551,7 @@ class My_accessiblesQuery(BaseModel):
         pass
 
     class Meta:
-        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n}\n\nquery my_accessibles {\n  accessiblerepresentations {\n    ...Representation\n  }\n}"
+        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n  omero {\n    scale\n  }\n}\n\nquery my_accessibles {\n  accessiblerepresentations {\n    ...Representation\n  }\n}"
 
 
 class ThumbnailQuery(BaseModel):
@@ -530,6 +614,19 @@ class Image_for_thumbnailQuery(BaseModel):
         document = "query image_for_thumbnail($id: ID!) {\n  image: thumbnail(id: $id) {\n    path: image\n    label: image\n  }\n}"
 
 
+class Expand_metricQuery(BaseModel):
+    """Creates a new representation"""
+
+    metric: Optional[MetricFragment]
+    "Get a single representation by ID"
+
+    class Arguments(BaseModel):
+        id: ID
+
+    class Meta:
+        document = "fragment Metric on Metric {\n  id\n  rep {\n    id\n  }\n  key\n  value\n  creator {\n    id\n  }\n  createdAt\n}\n\nquery expand_metric($id: ID!) {\n  metric(id: $id) {\n    ...Metric\n  }\n}"
+
+
 class Get_roisQuery(BaseModel):
     rois: Optional[List[Optional[ROIFragment]]]
     "All represetations"
@@ -762,15 +859,13 @@ class Upload_bioimageMutation(BaseModel):
     )
 
     class Arguments(BaseModel):
-        file: Upload
+        file: File
 
     class Meta:
-        document = "mutation upload_bioimage($file: Upload!) {\n  uploadOmeroFile(file: $file) {\n    id\n    file\n    type\n    name\n  }\n}"
+        document = "mutation upload_bioimage($file: ImageFile!) {\n  uploadOmeroFile(file: $file) {\n    id\n    file\n    type\n    name\n  }\n}"
 
 
-class Create_size_featureMutationCreatesizefeatureLabelRepresentation(
-    Representation, BaseModel
-):
+class Create_featureMutationCreatefeatureLabelRepresentation(Representation, BaseModel):
     """A Representation is a multi-dimensional Array that can do what ever it wants
 
 
@@ -780,34 +875,34 @@ class Create_size_featureMutationCreatesizefeatureLabelRepresentation(
     id: ID
 
 
-class Create_size_featureMutationCreatesizefeatureLabel(BaseModel):
+class Create_featureMutationCreatefeatureLabel(BaseModel):
     typename: Optional[Literal["Label"]] = Field(alias="__typename")
     id: ID
-    representation: Optional[
-        Create_size_featureMutationCreatesizefeatureLabelRepresentation
-    ]
+    representation: Optional[Create_featureMutationCreatefeatureLabelRepresentation]
 
 
-class Create_size_featureMutationCreatesizefeature(BaseModel):
-    typename: Optional[Literal["SizeFeature"]] = Field(alias="__typename")
+class Create_featureMutationCreatefeature(BaseModel):
+    typename: Optional[Literal["Feature"]] = Field(alias="__typename")
     id: ID
-    size: float
-    label: Optional[Create_size_featureMutationCreatesizefeatureLabel]
+    key: str
+    "The sKesyss"
+    value: Optional[FeatureValue]
+    "Value"
+    label: Optional[Create_featureMutationCreatefeatureLabel]
 
 
-class Create_size_featureMutation(BaseModel):
-    create_size_feature: Optional[Create_size_featureMutationCreatesizefeature] = Field(
-        alias="createSizeFeature"
-    )
+class Create_featureMutation(BaseModel):
+    createfeature: Optional[Create_featureMutationCreatefeature]
     "Creates a Sample"
 
     class Arguments(BaseModel):
         label: ID
-        size: float
+        key: Optional[str] = None
+        value: FeatureValue
         creator: Optional[ID] = None
 
     class Meta:
-        document = "mutation create_size_feature($label: ID!, $size: Float!, $creator: ID) {\n  createSizeFeature(label: $label, size: $size, creator: $creator) {\n    id\n    size\n    label {\n      id\n      representation {\n        id\n      }\n    }\n  }\n}"
+        document = "mutation create_feature($label: ID!, $key: String, $value: FeatureValue!, $creator: ID) {\n  createfeature(label: $label, key: $key, value: $value, creator: $creator) {\n    id\n    key\n    value\n    label {\n      id\n      representation {\n        id\n      }\n    }\n  }\n}"
 
 
 class Create_labelMutationCreatelabel(BaseModel):
@@ -841,12 +936,13 @@ class From_xarrayMutation(BaseModel):
         name: Optional[str] = None
         variety: Optional[RepresentationVarietyInput] = None
         origins: Optional[List[Optional[ID]]] = None
+        files: Optional[List[Optional[ID]]] = None
         tags: Optional[List[Optional[str]]] = None
         sample: Optional[ID] = None
         omero: Optional[OmeroRepresentationInput] = None
 
     class Meta:
-        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n}\n\nmutation from_xarray($xarray: XArray!, $name: String, $variety: RepresentationVarietyInput, $origins: [ID], $tags: [String], $sample: ID, $omero: OmeroRepresentationInput) {\n  fromXArray(\n    xarray: $xarray\n    name: $name\n    origins: $origins\n    tags: $tags\n    sample: $sample\n    omero: $omero\n    variety: $variety\n  ) {\n    ...Representation\n  }\n}"
+        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n  omero {\n    scale\n  }\n}\n\nmutation from_xarray($xarray: XArray!, $name: String, $variety: RepresentationVarietyInput, $origins: [ID], $files: [ID], $tags: [String], $sample: ID, $omero: OmeroRepresentationInput) {\n  fromXArray(\n    xarray: $xarray\n    name: $name\n    origins: $origins\n    tags: $tags\n    sample: $sample\n    omero: $omero\n    files: $files\n    variety: $variety\n  ) {\n    ...Representation\n  }\n}"
 
 
 class Double_uploadMutationX(Representation, BaseModel):
@@ -889,6 +985,22 @@ class Double_uploadMutation(BaseModel):
         document = "mutation double_upload($xarray: XArray!, $name: String, $origins: [ID], $tags: [String], $sample: ID, $omero: OmeroRepresentationInput) {\n  x: fromXArray(\n    xarray: $xarray\n    name: $name\n    origins: $origins\n    tags: $tags\n    sample: $sample\n    omero: $omero\n  ) {\n    id\n    store\n  }\n  y: fromXArray(\n    xarray: $xarray\n    name: $name\n    origins: $origins\n    tags: $tags\n    sample: $sample\n    omero: $omero\n  ) {\n    id\n    store\n  }\n}"
 
 
+class Update_representationMutation(BaseModel):
+    update_representation: Optional[RepresentationFragment] = Field(
+        alias="updateRepresentation"
+    )
+    "Updates an Representation (also retriggers meta-data retrieval from data stored in)"
+
+    class Arguments(BaseModel):
+        id: ID
+        tags: Optional[List[Optional[str]]] = None
+        sample: Optional[ID] = None
+        variety: Optional[RepresentationVarietyInput] = None
+
+    class Meta:
+        document = "fragment Representation on Representation {\n  sample {\n    id\n    name\n  }\n  type\n  id\n  store\n  variety\n  name\n  omero {\n    scale\n  }\n}\n\nmutation update_representation($id: ID!, $tags: [String], $sample: ID, $variety: RepresentationVarietyInput) {\n  updateRepresentation(rep: $id, tags: $tags, sample: $sample, variety: $variety) {\n    ...Representation\n  }\n}"
+
+
 class Create_thumbnailMutation(BaseModel):
     upload_thumbnail: Optional[ThumbnailFragment] = Field(alias="uploadThumbnail")
 
@@ -900,39 +1012,8 @@ class Create_thumbnailMutation(BaseModel):
         document = "fragment Thumbnail on Thumbnail {\n  id\n  image\n}\n\nmutation create_thumbnail($rep: ID!, $file: ImageFile!) {\n  uploadThumbnail(rep: $rep, file: $file) {\n    ...Thumbnail\n  }\n}"
 
 
-class Create_metricMutationCreatemetricRep(Representation, BaseModel):
-    """A Representation is a multi-dimensional Array that can do what ever it wants
-
-
-    @elements/rep:latest"""
-
-    typename: Optional[Literal["Representation"]] = Field(alias="__typename")
-    id: ID
-
-
-class Create_metricMutationCreatemetricCreator(BaseModel):
-    """A reflection on the real User"""
-
-    typename: Optional[Literal["User"]] = Field(alias="__typename")
-    id: ID
-
-
-class Create_metricMutationCreatemetric(BaseModel):
-    typename: Optional[Literal["Metric"]] = Field(alias="__typename")
-    id: ID
-    rep: Optional[Create_metricMutationCreatemetricRep]
-    "The Representatoin this Metric belongs to"
-    key: str
-    "The Key"
-    value: Optional[Dict]
-    creator: Optional[Create_metricMutationCreatemetricCreator]
-    created_at: str = Field(alias="createdAt")
-
-
 class Create_metricMutation(BaseModel):
-    create_metric: Optional[Create_metricMutationCreatemetric] = Field(
-        alias="createMetric"
-    )
+    create_metric: Optional[MetricFragment] = Field(alias="createMetric")
     "Creates a Representation"
 
     class Arguments(BaseModel):
@@ -940,10 +1021,10 @@ class Create_metricMutation(BaseModel):
         sample: Optional[ID] = None
         experiment: Optional[ID] = None
         key: str
-        value: Dict
+        value: MetricValue
 
     class Meta:
-        document = "mutation create_metric($rep: ID, $sample: ID, $experiment: ID, $key: String!, $value: GenericScalar!) {\n  createMetric(\n    rep: $rep\n    sample: $sample\n    experiment: $experiment\n    key: $key\n    value: $value\n  ) {\n    id\n    rep {\n      id\n    }\n    key\n    value\n    creator {\n      id\n    }\n    createdAt\n  }\n}"
+        document = "fragment Metric on Metric {\n  id\n  rep {\n    id\n  }\n  key\n  value\n  creator {\n    id\n  }\n  createdAt\n}\n\nmutation create_metric($rep: ID, $sample: ID, $experiment: ID, $key: String!, $value: MetricValue!) {\n  createMetric(\n    rep: $rep\n    sample: $sample\n    experiment: $experiment\n    key: $key\n    value: $value\n  ) {\n    ...Metric\n  }\n}"
 
 
 class Create_roiMutation(BaseModel):
@@ -960,6 +1041,34 @@ class Create_roiMutation(BaseModel):
         document = "fragment ROI on ROI {\n  id\n  vectors {\n    x\n    y\n    z\n  }\n  type\n  representation {\n    id\n  }\n  creator {\n    email\n    color\n  }\n}\n\nmutation create_roi($representation: ID!, $vectors: [InputVector]!, $creator: ID, $type: RoiTypeInput!) {\n  createROI(\n    representation: $representation\n    vectors: $vectors\n    type: $type\n    creator: $creator\n  ) {\n    ...ROI\n  }\n}"
 
 
+class Get_roiQuery(BaseModel):
+    roi: Optional[ROIFragment]
+    "Get a single representation by ID"
+
+    class Arguments(BaseModel):
+        id: ID
+
+    class Meta:
+        document = "fragment ROI on ROI {\n  id\n  vectors {\n    x\n    y\n    z\n  }\n  type\n  representation {\n    id\n  }\n  creator {\n    email\n    color\n  }\n}\n\nquery get_roi($id: ID!) {\n  roi(id: $id) {\n    ...ROI\n  }\n}"
+
+
+class Search_roisQueryRois(ROI, BaseModel):
+    typename: Optional[Literal["ROI"]] = Field(alias="__typename")
+    label: ID
+    value: ID
+
+
+class Search_roisQuery(BaseModel):
+    rois: Optional[List[Optional[Search_roisQueryRois]]]
+    "All represetations"
+
+    class Arguments(BaseModel):
+        search: str
+
+    class Meta:
+        document = "query search_rois($search: String!) {\n  rois(repname: $search) {\n    label: id\n    value: id\n  }\n}"
+
+
 class From_dfMutation(BaseModel):
     from_df: Optional[TableFragment] = Field(alias="fromDf")
     "Creates a Representation"
@@ -973,8 +1082,6 @@ class From_dfMutation(BaseModel):
 
 
 class Create_sampleMutationCreatesampleCreator(BaseModel):
-    """A reflection on the real User"""
-
     typename: Optional[Literal["User"]] = Field(alias="__typename")
     email: str
 
@@ -1141,6 +1248,50 @@ def search_omerofile(
     return execute(Search_omerofileQuery, {"search": search}, rath=rath).omerofiles
 
 
+async def aget_label(
+    representation: ID, instance: int, rath: MikroRath = None
+) -> Optional[Get_labelQueryLabelfor]:
+    """get_label
+
+
+
+    Arguments:
+        representation (ID): representation
+        instance (int): instance
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[Get_labelQueryLabelfor]"""
+    return (
+        await aexecute(
+            Get_labelQuery,
+            {"representation": representation, "instance": instance},
+            rath=rath,
+        )
+    ).label_for
+
+
+def get_label(
+    representation: ID, instance: int, rath: MikroRath = None
+) -> Optional[Get_labelQueryLabelfor]:
+    """get_label
+
+
+
+    Arguments:
+        representation (ID): representation
+        instance (int): instance
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[Get_labelQueryLabelfor]"""
+    return execute(
+        Get_labelQuery,
+        {"representation": representation, "instance": instance},
+        rath=rath,
+    ).label_for
+
+
 async def aexpand_representation(
     id: ID, rath: MikroRath = None
 ) -> Optional[RepresentationFragment]:
@@ -1477,6 +1628,34 @@ def image_for_thumbnail(
     return execute(Image_for_thumbnailQuery, {"id": id}, rath=rath).thumbnail
 
 
+async def aexpand_metric(id: ID, rath: MikroRath = None) -> Optional[MetricFragment]:
+    """expand_metric
+
+     Creates a new representation
+
+    Arguments:
+        id (ID): id
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[MetricFragment]"""
+    return (await aexecute(Expand_metricQuery, {"id": id}, rath=rath)).metric
+
+
+def expand_metric(id: ID, rath: MikroRath = None) -> Optional[MetricFragment]:
+    """expand_metric
+
+     Creates a new representation
+
+    Arguments:
+        id (ID): id
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[MetricFragment]"""
+    return execute(Expand_metricQuery, {"id": id}, rath=rath).metric
+
+
 async def aget_rois(
     representation: ID,
     type: Optional[List[Optional[RoiTypeInput]]] = None,
@@ -1936,14 +2115,14 @@ def negotiate(rath: MikroRath = None) -> Optional[Dict]:
 
 
 async def aupload_bioimage(
-    file: Upload, rath: MikroRath = None
+    file: File, rath: MikroRath = None
 ) -> Optional[Upload_bioimageMutationUploadomerofile]:
     """upload_bioimage
 
 
 
     Arguments:
-        file (Upload): file
+        file (File): file
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
@@ -1954,14 +2133,14 @@ async def aupload_bioimage(
 
 
 def upload_bioimage(
-    file: Upload, rath: MikroRath = None
+    file: File, rath: MikroRath = None
 ) -> Optional[Upload_bioimageMutationUploadomerofile]:
     """upload_bioimage
 
 
 
     Arguments:
-        file (Upload): file
+        file (File): file
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
@@ -1969,50 +2148,60 @@ def upload_bioimage(
     return execute(Upload_bioimageMutation, {"file": file}, rath=rath).upload_omero_file
 
 
-async def acreate_size_feature(
-    label: ID, size: float, creator: Optional[ID] = None, rath: MikroRath = None
-) -> Optional[Create_size_featureMutationCreatesizefeature]:
-    """create_size_feature
+async def acreate_feature(
+    label: ID,
+    value: FeatureValue,
+    key: Optional[str] = None,
+    creator: Optional[ID] = None,
+    rath: MikroRath = None,
+) -> Optional[Create_featureMutationCreatefeature]:
+    """create_feature
 
 
 
     Arguments:
         label (ID): label
-        size (float): size
+        value (FeatureValue): value
+        key (Optional[str], optional): key.
         creator (Optional[ID], optional): creator.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
-        Optional[Create_size_featureMutationCreatesizefeature]"""
+        Optional[Create_featureMutationCreatefeature]"""
     return (
         await aexecute(
-            Create_size_featureMutation,
-            {"label": label, "size": size, "creator": creator},
+            Create_featureMutation,
+            {"label": label, "key": key, "value": value, "creator": creator},
             rath=rath,
         )
-    ).create_size_feature
+    ).createfeature
 
 
-def create_size_feature(
-    label: ID, size: float, creator: Optional[ID] = None, rath: MikroRath = None
-) -> Optional[Create_size_featureMutationCreatesizefeature]:
-    """create_size_feature
+def create_feature(
+    label: ID,
+    value: FeatureValue,
+    key: Optional[str] = None,
+    creator: Optional[ID] = None,
+    rath: MikroRath = None,
+) -> Optional[Create_featureMutationCreatefeature]:
+    """create_feature
 
 
 
     Arguments:
         label (ID): label
-        size (float): size
+        value (FeatureValue): value
+        key (Optional[str], optional): key.
         creator (Optional[ID], optional): creator.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
-        Optional[Create_size_featureMutationCreatesizefeature]"""
+        Optional[Create_featureMutationCreatefeature]"""
     return execute(
-        Create_size_featureMutation,
-        {"label": label, "size": size, "creator": creator},
+        Create_featureMutation,
+        {"label": label, "key": key, "value": value, "creator": creator},
         rath=rath,
-    ).create_size_feature
+    ).createfeature
 
 
 async def acreate_label(
@@ -2086,6 +2275,7 @@ async def afrom_xarray(
     name: Optional[str] = None,
     variety: Optional[RepresentationVarietyInput] = None,
     origins: Optional[List[Optional[ID]]] = None,
+    files: Optional[List[Optional[ID]]] = None,
     tags: Optional[List[Optional[str]]] = None,
     sample: Optional[ID] = None,
     omero: Optional[OmeroRepresentationInput] = None,
@@ -2100,6 +2290,7 @@ async def afrom_xarray(
         name (Optional[str], optional): name.
         variety (Optional[RepresentationVarietyInput], optional): variety.
         origins (Optional[List[Optional[ID]]], optional): origins.
+        files (Optional[List[Optional[ID]]], optional): files.
         tags (Optional[List[Optional[str]]], optional): tags.
         sample (Optional[ID], optional): sample.
         omero (Optional[OmeroRepresentationInput], optional): omero.
@@ -2115,6 +2306,7 @@ async def afrom_xarray(
                 "name": name,
                 "variety": variety,
                 "origins": origins,
+                "files": files,
                 "tags": tags,
                 "sample": sample,
                 "omero": omero,
@@ -2129,6 +2321,7 @@ def from_xarray(
     name: Optional[str] = None,
     variety: Optional[RepresentationVarietyInput] = None,
     origins: Optional[List[Optional[ID]]] = None,
+    files: Optional[List[Optional[ID]]] = None,
     tags: Optional[List[Optional[str]]] = None,
     sample: Optional[ID] = None,
     omero: Optional[OmeroRepresentationInput] = None,
@@ -2143,6 +2336,7 @@ def from_xarray(
         name (Optional[str], optional): name.
         variety (Optional[RepresentationVarietyInput], optional): variety.
         origins (Optional[List[Optional[ID]]], optional): origins.
+        files (Optional[List[Optional[ID]]], optional): files.
         tags (Optional[List[Optional[str]]], optional): tags.
         sample (Optional[ID], optional): sample.
         omero (Optional[OmeroRepresentationInput], optional): omero.
@@ -2157,6 +2351,7 @@ def from_xarray(
             "name": name,
             "variety": variety,
             "origins": origins,
+            "files": files,
             "tags": tags,
             "sample": sample,
             "omero": omero,
@@ -2261,6 +2456,72 @@ def double_upload(
     )
 
 
+async def aupdate_representation(
+    id: ID,
+    tags: Optional[List[Optional[str]]] = None,
+    sample: Optional[ID] = None,
+    variety: Optional[RepresentationVarietyInput] = None,
+    rath: MikroRath = None,
+) -> Optional[RepresentationFragment]:
+    """update_representation
+
+
+     updateRepresentation: A Representation is a multi-dimensional Array that can do what ever it wants
+
+
+    @elements/rep:latest
+
+
+    Arguments:
+        id (ID): id
+        tags (Optional[List[Optional[str]]], optional): tags.
+        sample (Optional[ID], optional): sample.
+        variety (Optional[RepresentationVarietyInput], optional): variety.
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[RepresentationFragment]"""
+    return (
+        await aexecute(
+            Update_representationMutation,
+            {"id": id, "tags": tags, "sample": sample, "variety": variety},
+            rath=rath,
+        )
+    ).update_representation
+
+
+def update_representation(
+    id: ID,
+    tags: Optional[List[Optional[str]]] = None,
+    sample: Optional[ID] = None,
+    variety: Optional[RepresentationVarietyInput] = None,
+    rath: MikroRath = None,
+) -> Optional[RepresentationFragment]:
+    """update_representation
+
+
+     updateRepresentation: A Representation is a multi-dimensional Array that can do what ever it wants
+
+
+    @elements/rep:latest
+
+
+    Arguments:
+        id (ID): id
+        tags (Optional[List[Optional[str]]], optional): tags.
+        sample (Optional[ID], optional): sample.
+        variety (Optional[RepresentationVarietyInput], optional): variety.
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[RepresentationFragment]"""
+    return execute(
+        Update_representationMutation,
+        {"id": id, "tags": tags, "sample": sample, "variety": variety},
+        rath=rath,
+    ).update_representation
+
+
 async def acreate_thumbnail(
     rep: ID, file: File, rath: MikroRath = None
 ) -> Optional[ThumbnailFragment]:
@@ -2305,26 +2566,26 @@ def create_thumbnail(
 
 async def acreate_metric(
     key: str,
-    value: Dict,
+    value: MetricValue,
     rep: Optional[ID] = None,
     sample: Optional[ID] = None,
     experiment: Optional[ID] = None,
     rath: MikroRath = None,
-) -> Optional[Create_metricMutationCreatemetric]:
+) -> Optional[MetricFragment]:
     """create_metric
 
 
 
     Arguments:
         key (str): key
-        value (Dict): value
+        value (MetricValue): value
         rep (Optional[ID], optional): rep.
         sample (Optional[ID], optional): sample.
         experiment (Optional[ID], optional): experiment.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
-        Optional[Create_metricMutationCreatemetric]"""
+        Optional[MetricFragment]"""
     return (
         await aexecute(
             Create_metricMutation,
@@ -2342,26 +2603,26 @@ async def acreate_metric(
 
 def create_metric(
     key: str,
-    value: Dict,
+    value: MetricValue,
     rep: Optional[ID] = None,
     sample: Optional[ID] = None,
     experiment: Optional[ID] = None,
     rath: MikroRath = None,
-) -> Optional[Create_metricMutationCreatemetric]:
+) -> Optional[MetricFragment]:
     """create_metric
 
 
 
     Arguments:
         key (str): key
-        value (Dict): value
+        value (MetricValue): value
         rep (Optional[ID], optional): rep.
         sample (Optional[ID], optional): sample.
         experiment (Optional[ID], optional): experiment.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
-        Optional[Create_metricMutationCreatemetric]"""
+        Optional[MetricFragment]"""
     return execute(
         Create_metricMutation,
         {
@@ -2441,6 +2702,66 @@ def create_roi(
     ).create_roi
 
 
+async def aget_roi(id: ID, rath: MikroRath = None) -> Optional[ROIFragment]:
+    """get_roi
+
+
+
+    Arguments:
+        id (ID): id
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[ROIFragment]"""
+    return (await aexecute(Get_roiQuery, {"id": id}, rath=rath)).roi
+
+
+def get_roi(id: ID, rath: MikroRath = None) -> Optional[ROIFragment]:
+    """get_roi
+
+
+
+    Arguments:
+        id (ID): id
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[ROIFragment]"""
+    return execute(Get_roiQuery, {"id": id}, rath=rath).roi
+
+
+async def asearch_rois(
+    search: str, rath: MikroRath = None
+) -> Optional[List[Optional[Search_roisQueryRois]]]:
+    """search_rois
+
+
+
+    Arguments:
+        search (str): search
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[List[Optional[Search_roisQueryRois]]]"""
+    return (await aexecute(Search_roisQuery, {"search": search}, rath=rath)).rois
+
+
+def search_rois(
+    search: str, rath: MikroRath = None
+) -> Optional[List[Optional[Search_roisQueryRois]]]:
+    """search_rois
+
+
+
+    Arguments:
+        search (str): search
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[List[Optional[Search_roisQueryRois]]]"""
+    return execute(Search_roisQuery, {"search": search}, rath=rath).rois
+
+
 async def afrom_df(
     df: DataFrame, name: str, rath: MikroRath = None
 ) -> Optional[TableFragment]:
@@ -2613,5 +2934,5 @@ def create_experiment(
     ).create_experiment
 
 
-OmeroRepresentationInput.update_forward_refs()
 DescendendInput.update_forward_refs()
+OmeroRepresentationInput.update_forward_refs()
