@@ -5,6 +5,9 @@ Custom scalars for Mikro.
 """
 
 
+import os
+from typing import Any
+import uuid
 import xarray as xr
 import pyarrow.parquet as pq
 import pandas as pd
@@ -15,6 +18,10 @@ class XArrayConversionException(Exception):
     pass
 
 
+MetricValue = Any
+FeatureValue = Any
+
+
 class ArrayInput:
     """A custom scalar for wrapping of every supported array like structure on
     the mikro platform. This will then be uploaded to the datalayer."""
@@ -234,14 +241,25 @@ class File:
         self.value = value
 
     def download(self, dl=None):
+        from mikro.datalayer import current_datalayer
+        import requests
+        import shutil
+
         dl = dl or current_datalayer.get()
         url = f"{dl.endpoint_url}{self.value}"
-        local_filename = "test.tif"
-        # requests.get(url, stream=True) as r:
-        #    with open(local_filename, "wb") as f:
-        #        shutil.copyfileobj(r.raw, f)
+        x = str(uuid.uuid4())
+        local_filename = f"{x}.tif"
+        with requests.get(url, stream=True) as r:
+            with open(local_filename, "wb") as f:
+                shutil.copyfileobj(r.raw, f)
+                return local_filename
 
-        return local_filename
+    def __enter__(self):
+        self.local_file = self.download()
+        return self.local_file
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        os.remove(self.local_file)
 
     @classmethod
     def __get_validators__(cls):
