@@ -7,13 +7,12 @@ You can of course overwrite this in your app if you need to expand to a more com
 
 """
 
-
-from arkitekt.widgets import ImageReturnWidget
+from rekuest.widgets import CustomReturnWidget
 
 
 try:
-    from arkitekt.structures.default import get_default_structure_registry
-    from arkitekt.widgets import SearchWidget
+    from rekuest.structures.default import get_default_structure_registry
+    from rekuest.widgets import SearchWidget, ImageReturnWidget
     from mikro.api.schema import *
 
     structure_reg = get_default_structure_registry()
@@ -23,12 +22,25 @@ try:
         expand=aexpand_representation,
         default_widget=SearchWidget(query=Search_representationQuery.Meta.document),
     )
+    structure_reg.register_as_structure(
+        MetricFragment,
+        identifier="@mikro/metric",
+        expand=aexpand_metric,
+        default_widget=None,
+        default_returnwidget=CustomReturnWidget(hook="metric"),
+    )
     structure_reg.register_as_structure(
         SampleFragment,
         identifier="@mikro/sample",
         expand=aexpand_sample,
         default_widget=SearchWidget(query=Search_sampleQuery.Meta.document),
     )
+    structure_reg.register_as_structure(
+        TableFragment,
+        identifier="@mikro/table",
+        expand=aexpand_table,
+        default_widget=SearchWidget(query=Search_tablesQuery.Meta.document),
+    )
     structure_reg.register_as_structure(
         ExperimentFragment,
         identifier="@mikro/experiment",
@@ -50,5 +62,11 @@ try:
         expand=aexpand_omerofile,
         default_widget=SearchWidget(query=Search_omerofileQuery.Meta.document),
     )
+    structure_reg.register_as_structure(
+        ROIFragment,
+        identifier="@mikro/roi",
+        expand=aget_roi,
+        default_widget=SearchWidget(query=Search_roisQuery.Meta.document),
+    )
 except ImportError:
     structure_reg = None
